/**
 * Copyright 2006 Ramona Dromereschi
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 **/
package com.puzzle.game.states.impl;

import com.puzzle.game.states.IMoveState;
import com.puzzle.game.impl.PuzzleModel;
import com.puzzle.game.impl.PuzzleView;

/**
 * Created by IntelliJ IDEA.
 * <p/>
 * User: Ramona Dromereschi
 * <p/>
 * Date: Oct 25, 2006
 * Time: 2:55:38 PM
 * <p/>
 * The abstract move state.
 */
public abstract class AbstractMoveState implements IMoveState {
    /** The puzzle model. */
    protected PuzzleModel model;
    /** The puzzle view. */
    protected PuzzleView view;

    /**
     * After the state methos is called, this method refreshes the view data.
     */
    protected void refreshView() {
        model.setCountMoves(model.getCountMoves() + 1);
        view.repaint();
    }

    /**
     * Sets the current status of the puzzle.
     * @param incX increment X
     * @param incY increment Y
     */
    protected void setCurrentValue(int incX, int incY) {
        int number = model.getMatPuzzle()[model.getCurrentY() + incY][model.getCurrentX() + incX];
        model.getMatPuzzle()[model.getCurrentY() + incY][model.getCurrentX() + incX] = 0;
        model.getMatPuzzle()[model.getCurrentY()][model.getCurrentX()] = number;
        model.setCurrentX(model.getCurrentX() + incX);
        model.setCurrentY(model.getCurrentY() + incY);
    }
}
