/**
 * Copyright 2006 Ramona Dromereschi
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 **/
package com.puzzle.settings;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.ImageIcon;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by IntelliJ IDEA.
 * <p/>
 * User: Ramona Dromereschi
 * <p/>
 * Date: Oct 25, 2006
 * Time: 4:14:33 PM
 * <p/>
 * The settings panel class.
 */
public class SettingsPanel extends JPanel {
    /** The supported game levels. */
    private String[] levels = new String[]{"Very Easy", "Easy", "Medium", "Hard", "Very Hard"};
    /** The levels combo-box. */
    private JComboBox levelsCombo = new JComboBox(levels);
    /** The new game button. */
    private JButton newGameButton = new JButton("New Game");
    /** The listeners to be notified about a start new game event. */
    private List<StartGameListener> listeners = new ArrayList<StartGameListener>();

    /**
     * The class contructor.
     */
    public SettingsPanel(ImageIcon img) {
        newGameButton.setIcon(img);
        initView();
        initObservers();
    }

    /**
     * Adds a start new game observer.
     * @param listener the observer
     */
    public synchronized void addStartGameListener(StartGameListener listener) {
        listeners.add(listener);
    }

    /**
     * Removes an existent start new game observer.
     * @param listener the observer
     */
    public synchronized void removeStartGameListener(StartGameListener listener) {
        listeners.remove(listener);
    }

    /**
     * Notifies the start new game observers.
     */
    private synchronized void notifyStartGameObservers() {
        for (StartGameListener listener : listeners) {
            listener.startNewGame(levelsCombo.getSelectedIndex());
        }
    }

    /**
     * Initializes the user interface.
     */
    private void initView() {
        setLayout(new BorderLayout());
        JPanel comboPanel = new JPanel();
        comboPanel.setLayout(new FlowLayout(FlowLayout.CENTER, 10, 10));
        comboPanel.add(new JLabel("Level"));
        comboPanel.add(levelsCombo);
        add(comboPanel, BorderLayout.CENTER);
        add(newGameButton, BorderLayout.SOUTH);
    }

    /**
     * Initializes the observers.
     */
    private void initObservers() {
        newGameButton.addActionListener(new ActionListener(){
            public void actionPerformed(ActionEvent actionEvent) {
                notifyStartGameObservers();
            }
        });
    }
}
